@@ -6,18 +6,22 @@ package org.gcube.portlets.user.td.wizardwidget.client;
 import java.util.ArrayList;
 
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
+import org.gcube.portlets.user.td.wizardwidget.client.dataresource.ResourceBundle;
 import org.gcube.portlets.user.td.wizardwidget.client.util.ErrorMessageBox;
 
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.core.client.Callback;
 import com.google.gwt.user.client.Command;
 import com.google.gwt.user.client.ui.Widget;
-import com.google.web.bindery.event.shared.SimpleEventBus;
 import com.google.web.bindery.event.shared.EventBus;
+import com.google.web.bindery.event.shared.SimpleEventBus;
+import com.sencha.gxt.cell.core.client.ButtonCell.IconAlign;
 import com.sencha.gxt.core.client.resources.ThemeStyles;
+import com.sencha.gxt.core.client.util.Margins;
 import com.sencha.gxt.widget.core.client.Dialog;
 import com.sencha.gxt.widget.core.client.Window;
 import com.sencha.gxt.widget.core.client.button.TextButton;
+import com.sencha.gxt.widget.core.client.container.BoxLayoutContainer.BoxLayoutData;
 import com.sencha.gxt.widget.core.client.container.CardLayoutContainer;
 import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer;
 import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer.VerticalLayoutData;
@@ -64,6 +68,8 @@ public class WizardWindow extends Window {
 	protected ArrayList<WizardListener> listeners;
 
 	protected EventBus eventBus;
+	
+	protected ToolBar cardMoveToolBar;
 
 	/**
 	 * Create a new Wizard Window with the specified title.
@@ -96,21 +102,27 @@ public class WizardWindow extends Window {
 		cardContainer = new CardLayoutContainer();
 		container.add(cardContainer, new VerticalLayoutData(1, 1));
 
-		ToolBar toolbar = new ToolBar();
-		toolbar.addStyleName(ThemeStyles.getStyle().borderTop());
+		cardMoveToolBar = new ToolBar();
+		cardMoveToolBar.setSpacing(2);
+		cardMoveToolBar.addStyleName(ThemeStyles.getStyle().borderTop());
 
 		backButton = new TextButton(BUTTONBACKLABEL);
+		backButton.setIcon(ResourceBundle.INSTANCE.wizardPrevious());
+		backButton.setIconAlign(IconAlign.LEFT);
+	
 		backButton.setEnabled(false);
 		backButton.setTabIndex(1001);
-		toolbar.add(backButton);
-		toolbar.add(new FillToolItem());
+		cardMoveToolBar.add(backButton,new BoxLayoutData(new Margins(1)));
+		cardMoveToolBar.add(new FillToolItem());
 
 		nextButton = new TextButton(BUTTONNEXTLABEL);
+		nextButton.setIcon(ResourceBundle.INSTANCE.wizardNext());
+		nextButton.setIconAlign(IconAlign.RIGHT);
 		nextButton.setTabIndex(1000);
-		toolbar.add(nextButton);
+		cardMoveToolBar.add(nextButton, new BoxLayoutData(new Margins(1)));
 
-		toolbar.setLayoutData(new VerticalLayoutData(1, -1));
-		container.add(toolbar);
+		cardMoveToolBar.setLayoutData(new VerticalLayoutData(1, -1));
+		container.add(cardMoveToolBar);
 
 		SelectHandler selectionHandler = new SelectHandler() {
 
@@ -268,6 +280,9 @@ public class WizardWindow extends Window {
 	 */
 	public void setNextButtonToFinish() {
 		nextButton.setText(BUTTONFINISHLABEL);
+		nextButton.setIcon(ResourceBundle.INSTANCE.wizardGo());
+		nextButton.setIconAlign(IconAlign.RIGHT);
+		nextButton.getElement().applyStyles("margin-right:2px");
 		nextButtonAction = new Command() {
 
 			public void execute() {
